#
# Konstantin Volkov <wolf@virtuozzo.com>
# Denis Silakov <dsilakov@virtuozzo.com>
#
# Copyright (c) 2015-2019 Virtuozzo International GmbH. All rights reserved.
#
# This copyrighted material is made available to anyone wishing to use, modify,
# copy, or redistribute it subject to the terms and conditions of the GNU
# General Public License v.2.  This program is distributed in the hope that it
# will be useful, but WITHOUT ANY WARRANTY expressed or implied, including the
# implied warranties of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 51
# Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  Any Virtuozzo
# trademarks that are incorporated in the source code or documentation are not
# subject to the GNU General Public License and may only be used or replicated
# with the express permission of Virtuozzo.
#
import string

from pykickstart.base import *
from pykickstart.errors import *
from pykickstart.options import *
from pykickstart.version import VZ7, VZ8

import warnings
import gettext
_ = lambda x: gettext.ldgettext("pykickstart", x).decode('utf-8')

class PSBM5_Vznetcfg(KickstartCommand):
    removedKeywords = KickstartCommand.removedKeywords
    removedAttrs = KickstartCommand.removedAttrs

    def __init__(self, writePriority=0, *args, **kwargs):
        KickstartCommand.__init__(self, writePriority, *args, **kwargs)
        self.op = self._getParser()
        self.net = kwargs.get("net", "")
        self.vlan = kwargs.get("vlan", "")

    def __str__(self):
        retval = KickstartCommand.__str__(self)

        if self.net or self.vlan:
            retval += "vznetcfg"

            if self.net:
                retval += " --net=%s" % self.net
            if self.vlan:
                retval += " --vlan=%s" % self.vlan

            retval += "\n"

        return retval

    def _getParser(self):
        op = KSOptionParser(version=VZ7, prog="vznetcfg", description="vznetcfg")
        op.add_argument("--net", dest="net", action="store", version=VZ7, help="")
        op.add_argument("--vlan", dest="vlan", action="store", version=VZ7, help="")
        return op

    def parse(self, args):
        if len(args) == 0:
            raise KickstartParseError(_("Command %s requires at least one argument") % "vznetcfg", lineno=self.lineno)

        (opts, extra) = self.op.parse_args(args=args, lineno=self.lineno)

        self._setToSelf(self.op, opts)

        return self

class VZ7_Vznetcfg(PSBM5_Vznetcfg):
    def __str__(self):
        return KickstartCommand.__str__(self)

    def parse(self, args):
        warnings.warn("The vznetcfg parameter is not used anymore and will be ignored.")

class VZ8_Vznetcfg(VZ7_Vznetcfg):
    pass
