#
# Denis Silakov <dsilakov@virtuozzo.com>
#
# Copyright (c) 2020 Virtuozzo International GmbH. All rights reserved.
#
# This copyrighted material is made available to anyone wishing to use, modify,
# copy, or redistribute it subject to the terms and conditions of the GNU
# General Public License v.2.  This program is distributed in the hope that it
# will be useful, but WITHOUT ANY WARRANTY expressed or implied, including the
# implied warranties of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 51
# Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  Any Virtuozzo
# trademarks that are incorporated in the source code or documentation are not
# subject to the GNU General Public License and may only be used or replicated
# with the express permission of Virtuozzo.

__all__ = ["VZ8Handler"]

from pykickstart import commands
from pykickstart.base import BaseHandler
from pykickstart.version import VZ8

class VZ8Handler(BaseHandler):
    version = VZ8

    commandMap = {
        "auth": commands.authconfig.F28_Authconfig,
        "authconfig": commands.authconfig.F28_Authconfig,
        "authselect": commands.authselect.F28_Authselect,
        "autopart": commands.autopart.RHEL8_AutoPart,
        "autostep": commands.autostep.FC3_AutoStep,
        "bootloader": commands.bootloader.RHEL8_Bootloader,
        "btrfs": commands.btrfs.RHEL8_BTRFS,
        "cdrom": commands.cdrom.FC3_Cdrom,
        "cep": commands.cep.VZ8_CEP,
        "clearpart": commands.clearpart.F28_ClearPart,
        "cmdline": commands.displaymode.F26_DisplayMode,
#        "container": commands.container.VZ8_Container,
        "device": commands.device.F24_Device,
        "deviceprobe": commands.deviceprobe.F29_DeviceProbe,
        "dmraid": commands.dmraid.F24_DmRaid,
        "driverdisk": commands.driverdisk.F14_DriverDisk,
        "module" : commands.module.RHEL8_Module,
        "eula": commands.eula.F20_Eula,
        "fcoe": commands.fcoe.RHEL8_Fcoe,
        "firewall": commands.firewall.F28_Firewall,
        "firstboot": commands.firstboot.FC3_Firstboot,
        "graphical": commands.displaymode.F26_DisplayMode,
        "group": commands.group.F12_Group,
        "halt": commands.reboot.F23_Reboot,
        "harddrive": commands.harddrive.FC3_HardDrive,
        "hmc" : commands.hmc.F28_Hmc,
        "ignoredisk": commands.ignoredisk.F29_IgnoreDisk,
        "install": commands.install.F29_Install,
        "iscsi": commands.iscsi.F17_Iscsi,
        "iscsiname": commands.iscsiname.FC6_IscsiName,
        "key": commands.key.RHEL5_Key,
        "keyboard": commands.keyboard.F18_Keyboard,
        "lang": commands.lang.F19_Lang,
        "liveimg": commands.liveimg.F19_Liveimg,
        "logging": commands.logging.FC6_Logging,
        "logvol": commands.logvol.VZ8_LogVol,
        "mediacheck": commands.mediacheck.FC4_MediaCheck,
        "method": commands.method.F28_Method,
        "mount": commands.mount.F27_Mount,
        "multipath": commands.multipath.F24_MultiPath,
        "network": commands.network.F27_Network,
        "nfs": commands.nfs.FC6_NFS,
        "nosfxtemplate": commands.nosfxtemplate.VZ8_Nosfxtemplate,
        "nvdimm": commands.nvdimm.F28_Nvdimm,
        "ostreesetup": commands.ostreesetup.RHEL8_OSTreeSetup,
        "part": commands.partition.VZ8_Partition,
        "partition": commands.partition.VZ8_Partition,
        "poweroff": commands.reboot.F23_Reboot,
        "pstorage": commands.vstorage.VZ8_Vstorage,
        "prlnet": commands.prlnet.VZ8_Prlnet,
        "pvaagent": commands.pvaagent.VZ8_Pvaagent,
        "pvamn": commands.pvamn.VZ8_Pvamn,
        "pvaurl": commands.pvaurl.VZ8_Pvaurl,
        "raid": commands.raid.RHEL8_Raid,
        "readykernel": commands.readykernel.VZ8_Readykernel,
        "realm": commands.realm.F19_Realm,
        "reboot": commands.reboot.F23_Reboot,
#        "register_vaagent": commands.register_vaagent.VZ8_RegisterVAagent,
#        "register_vstorage_ui": commands.register_vstorage_ui.VZ8_RegisterVStorageUI,
        "repo": commands.repo.RHEL8_Repo,
        "reqpart": commands.reqpart.F23_ReqPart,
        "rescue": commands.rescue.F10_Rescue,
        "rootpw": commands.rootpw.F18_RootPw,
        "selinux": commands.selinux.FC3_SELinux,
        "services": commands.services.FC6_Services,
        "shutdown": commands.reboot.F23_Reboot,
        "skipx": commands.skipx.FC3_SkipX,
        "snapshot": commands.snapshot.F26_Snapshot,
        "squashinstall": commands.squashinstall.VZ8_Squashinstall,
        "sshpw": commands.sshpw.F24_SshPw,
        "sshkey": commands.sshkey.F22_SshKey,
        "syspurpose" : commands.syspurpose.RHEL8_Syspurpose,
        "text": commands.displaymode.F26_DisplayMode,
        "timezone": commands.timezone.F25_Timezone,
        "up2date": commands.up2date.VZ8_Up2date,
        "updates": commands.updates.F7_Updates,
        "url": commands.url.RHEL8_Url,
        "user": commands.user.F24_User,
        "vnc": commands.vnc.F9_Vnc,
        "volgroup": commands.volgroup.RHEL8_VolGroup,
        "vstorage": commands.vstorage.VZ8_Vstorage,
        "vziptables": commands.vziptables.VZ8_Vziptables,
        "vznetcfg": commands.vznetcfg.VZ8_Vznetcfg,
        "vztturlmap": commands.vztturlmap.VZ8_Vztturlmap,
        "xconfig": commands.xconfig.F14_XConfig,
        "zerombr": commands.zerombr.F9_ZeroMbr,
        "zfcp": commands.zfcp.F14_ZFCP,
    }

    dataMap = {
        "BTRFSData": commands.btrfs.F23_BTRFSData,
#	"ContainerData" : commands.container.VZ8_ContainerData,
        "DriverDiskData": commands.driverdisk.F14_DriverDiskData,
        "DeviceData": commands.device.F8_DeviceData,
        "DmRaidData": commands.dmraid.FC6_DmRaidData,
        "ModuleData" : commands.module.RHEL8_ModuleData,
        "FcoeData": commands.fcoe.RHEL8_FcoeData,
        "GroupData": commands.group.F12_GroupData,
        "IscsiData": commands.iscsi.F17_IscsiData,
        "LogVolData": commands.logvol.VZ8_LogVolData,
        "MountData": commands.mount.F27_MountData,
        "MultiPathData": commands.multipath.FC6_MultiPathData,
        "NetworkData": commands.network.F27_NetworkData,
        "NvdimmData": commands.nvdimm.F28_NvdimmData,
        "PartData": commands.partition.VZ8_PartData,
        "RaidData": commands.raid.RHEL8_RaidData,
        "RepoData": commands.repo.RHEL8_RepoData,
        "SnapshotData": commands.snapshot.F26_SnapshotData,
        "SshPwData": commands.sshpw.F24_SshPwData,
        "SshKeyData": commands.sshkey.F22_SshKeyData,
        "UserData": commands.user.F19_UserData,
        "VolGroupData": commands.volgroup.RHEL8_VolGroupData,
        "ZFCPData": commands.zfcp.F14_ZFCPData,
    }
